pub struct BucketSpan {
pub offset: i32,
pub length: u32,
}Available on crate feature
prometheus_protobuf only.Expand description
A BucketSpan defines a number of consecutive buckets in a native histogram with their offset. Logically, it would be more straightforward to include the bucket counts in the Span. However, the protobuf representation is more compact in the way the data is structured here (with all the buckets in a single array separate from the Spans).
Fields
offset: i32Gap to previous span, or starting point for 1st span (which can be negative).
length: u32Length of consecutive buckets.