EncodeMetric

Trait EncodeMetric 

pub trait EncodeMetric {
    // Required methods
    fn encode(&self, encoder: MetricEncoder<'_>) -> Result<(), Error>;
    fn metric_type(&self) -> MetricType;

    // Provided method
    fn is_empty(&self) -> bool { ... }
}
Trait implemented by each metric type, e.g. Counter, to implement its encoding in the OpenMetric text format.

Required Methods

fn encode(&self, encoder: MetricEncoder<'_>) -> Result<(), Error>

Encode the given instance in the OpenMetrics text encoding.

fn metric_type(&self) -> MetricType

The OpenMetrics metric type of the instance.

Provided Methods

fn is_empty(&self) -> bool

Check if the metric is empty.

An empty metric is a metric that has no data to encode, and thus should not have any descriptor in the final output.

By default, this returns false, ensuring the metric and its description is always encoded.