pub struct Histogram {Show 16 fields
pub sample_count: u64,
pub sample_count_float: f64,
pub sample_sum: f64,
pub bucket: Vec<Bucket>,
pub start_timestamp: Option<Timestamp>,
pub schema: i32,
pub zero_threshold: f64,
pub zero_count: u64,
pub zero_count_float: f64,
pub negative_span: Vec<BucketSpan>,
pub negative_delta: Vec<i64>,
pub negative_count: Vec<f64>,
pub positive_span: Vec<BucketSpan>,
pub positive_delta: Vec<i64>,
pub positive_count: Vec<f64>,
pub exemplars: Vec<Exemplar>,
}prometheus_protobuf only.Fields
sample_count: u64sample_count_float: f64Overrides sample_count if > 0.
sample_sum: f64bucket: Vec<Bucket>Buckets for the classic histogram.
Ordered in increasing order of upper_bound, +Inf bucket is optional.
start_timestamp: Option<Timestamp>schema: i32schema defines the bucket schema. Currently, valid numbers are -4 <= n <= 8. They are all for base-2 bucket schemas, where 1 is a bucket boundary in each case, and then each power of two is divided into 2^n logarithmic buckets. Or in other words, each bucket boundary is the previous boundary times 2^(2^-n). In the future, more bucket schemas may be added using numbers < -4 or > 8.
zero_threshold: f64Breadth of the zero bucket.
zero_count: u64Count in zero bucket.
zero_count_float: f64Overrides sb_zero_count if > 0.
negative_span: Vec<BucketSpan>Negative buckets for the native histogram.
negative_delta: Vec<i64>Use either “negative_delta” or “negative_count”, the former for regular histograms with integer counts, the latter for float histograms.
Count delta of each bucket compared to previous one (or to zero for 1st bucket).
negative_count: Vec<f64>Absolute count of each bucket.
positive_span: Vec<BucketSpan>Positive buckets for the native histogram. Use a no-op span (offset 0, length 0) for a native histogram without any observations yet and with a zero_threshold of 0. Otherwise, it would be indistinguishable from a classic histogram.
positive_delta: Vec<i64>Use either “positive_delta” or “positive_count”, the former for regular histograms with integer counts, the latter for float histograms.
Count delta of each bucket compared to previous one (or to zero for 1st bucket).
positive_count: Vec<f64>Absolute count of each bucket.
exemplars: Vec<Exemplar>Only used for native histograms. These exemplars MUST have a timestamp.